@@ -13,15 +13,17 @@ import pickle
 import warnings
 from collections import defaultdict
 from copy import copy
+from datetime import datetime
 from os import path
-from typing import Any, Callable, Dict, Generator, Iterator, List, Set, Tuple, Union, cast
+from typing import (TYPE_CHECKING, Any, Callable, Dict, Generator, Iterator, List, Optional,
+                    Set, Tuple, Union)
 
 from docutils import nodes
 from docutils.nodes import Node
 
 from sphinx import addnodes
 from sphinx.config import Config
-from sphinx.deprecation import RemovedInSphinx40Warning
+from sphinx.deprecation import RemovedInSphinx60Warning
 from sphinx.domains import Domain
 from sphinx.environment.adapters.toctree import TocTree
 from sphinx.errors import BuildEnvironmentError, DocumentError, ExtensionError, SphinxError
@@ -35,15 +37,16 @@ from sphinx.util.i18n import CatalogRepository, docname_to_domain
 from sphinx.util.nodes import is_translatable
 from sphinx.util.osutil import canon_path, os_path
 
-if False:
-    # For type annotation
+if TYPE_CHECKING:
     from sphinx.application import Sphinx
     from sphinx.builders import Builder
 
 
 logger = logging.getLogger(__name__)
 
-default_settings = {
+default_settings: Dict[str, Any] = {
+    'auto_id_prefix': 'id',
+    'embed_images': False,
     'embed_stylesheet': False,
     'cloak_email_addresses': True,
     'pep_base_url': 'https://www.python.org/dev/peps/',
@@ -53,10 +56,11 @@ default_settings = {
     'input_encoding': 'utf-8-sig',
     'doctitle_xform': False,
     'sectsubtitle_xform': False,
+    'section_self_link': False,
     'halt_level': 5,
     'file_insertion_enabled': True,
     'smartquotes_locales': [],
-}  # type: Dict[str, Any]
+}
 
 # This is increased every time an environment attribute is added
 # or changed to properly invalidate pickle files.
@@ -75,10 +79,10 @@ CONFIG_CHANGED_REASON = {
 }
 
 
-versioning_conditions = {
+versioning_conditions: Dict[str, Union[bool, Callable]] = {
     'none': False,
     'text': is_translatable,
-}  # type: Dict[str, Union[bool, Callable]]
+}
 
 
 class BuildEnvironment:
@@ -88,24 +92,24 @@ class BuildEnvironment:
     transformations to resolve links to them.
     """
 
-    domains = None  # type: Dict[str, Domain]
+    domains: Dict[str, Domain]
 
     # --------- ENVIRONMENT INITIALIZATION -------------------------------------
 
     def __init__(self, app: "Sphinx" = None):
-        self.app = None                  # type: Sphinx
-        self.doctreedir = None           # type: str
-        self.srcdir = None               # type: str
-        self.config = None               # type: Config
-        self.config_status = None        # type: int
-        self.config_status_extra = None  # type: str
-        self.events = None               # type: EventManager
-        self.project = None              # type: Project
-        self.version = None              # type: Dict[str, str]
+        self.app: Sphinx = None
+        self.doctreedir: str = None
+        self.srcdir: str = None
+        self.config: Config = None
+        self.config_status: int = None
+        self.config_status_extra: str = None
+        self.events: EventManager = None
+        self.project: Project = None
+        self.version: Dict[str, str] = None
 
         # the method of doctree versioning; see set_versioning_method
-        self.versioning_condition = None  # type: Union[bool, Callable]
-        self.versioning_compare = None  # type: bool
+        self.versioning_condition: Union[bool, Callable] = None
+        self.versioning_compare: bool = None
 
         # all the registered domains, set by the application
         self.domains = {}
@@ -117,74 +121,74 @@ class BuildEnvironment:
         # All "docnames" here are /-separated and relative and exclude
         # the source suffix.
 
-        self.all_docs = {}          # type: Dict[str, float]
-                                    # docname -> mtime at the time of reading
-                                    # contains all read docnames
-        self.dependencies = defaultdict(set)    # type: Dict[str, Set[str]]
-                                    # docname -> set of dependent file
-                                    # names, relative to documentation root
-        self.included = defaultdict(set)        # type: Dict[str, Set[str]]
-                                    # docname -> set of included file
-                                    # docnames included from other documents
-        self.reread_always = set()  # type: Set[str]
-                                    # docnames to re-read unconditionally on
-                                    # next build
+        # docname -> mtime at the time of reading
+        # contains all read docnames
+        self.all_docs: Dict[str, float] = {}
+        # docname -> set of dependent file
+        # names, relative to documentation root
+        self.dependencies: Dict[str, Set[str]] = defaultdict(set)
+        # docname -> set of included file
+        # docnames included from other documents
+        self.included: Dict[str, Set[str]] = defaultdict(set)
+        # docnames to re-read unconditionally on next build
+        self.reread_always: Set[str] = set()
 
         # File metadata
-        self.metadata = defaultdict(dict)       # type: Dict[str, Dict[str, Any]]
-                                                # docname -> dict of metadata items
+        # docname -> dict of metadata items
+        self.metadata: Dict[str, Dict[str, Any]] = defaultdict(dict)
 
         # TOC inventory
-        self.titles = {}            # type: Dict[str, nodes.title]
-                                    # docname -> title node
-        self.longtitles = {}        # type: Dict[str, nodes.title]
-                                    # docname -> title node; only different if
-                                    # set differently with title directive
-        self.tocs = {}              # type: Dict[str, nodes.bullet_list]
-                                    # docname -> table of contents nodetree
-        self.toc_num_entries = {}   # type: Dict[str, int]
-                                    # docname -> number of real entries
+        # docname -> title node
+        self.titles: Dict[str, nodes.title] = {}
+        # docname -> title node; only different if
+        # set differently with title directive
+        self.longtitles: Dict[str, nodes.title] = {}
+        # docname -> table of contents nodetree
+        self.tocs: Dict[str, nodes.bullet_list] = {}
+        # docname -> number of real entries
+        self.toc_num_entries: Dict[str, int] = {}
 
         # used to determine when to show the TOC
         # in a sidebar (don't show if it's only one item)
-        self.toc_secnumbers = {}    # type: Dict[str, Dict[str, Tuple[int, ...]]]
-                                    # docname -> dict of sectionid -> number
-        self.toc_fignumbers = {}    # type: Dict[str, Dict[str, Dict[str, Tuple[int, ...]]]]
-                                    # docname -> dict of figtype ->
-                                    # dict of figureid -> number
+        # docname -> dict of sectionid -> number
+        self.toc_secnumbers: Dict[str, Dict[str, Tuple[int, ...]]] = {}
+        # docname -> dict of figtype -> dict of figureid -> number
+        self.toc_fignumbers: Dict[str, Dict[str, Dict[str, Tuple[int, ...]]]] = {}
 
-        self.toctree_includes = {}  # type: Dict[str, List[str]]
-                                    # docname -> list of toctree includefiles
-        self.files_to_rebuild = {}  # type: Dict[str, Set[str]]
-                                    # docname -> set of files
-                                    # (containing its TOCs) to rebuild too
-        self.glob_toctrees = set()  # type: Set[str]
-                                    # docnames that have :glob: toctrees
-        self.numbered_toctrees = set()  # type: Set[str]
-                                        # docnames that have :numbered: toctrees
+        # docname -> list of toctree includefiles
+        self.toctree_includes: Dict[str, List[str]] = {}
+        # docname -> set of files (containing its TOCs) to rebuild too
+        self.files_to_rebuild: Dict[str, Set[str]] = {}
+        # docnames that have :glob: toctrees
+        self.glob_toctrees: Set[str] = set()
+        # docnames that have :numbered: toctrees
+        self.numbered_toctrees: Set[str] = set()
 
         # domain-specific inventories, here to be pickled
-        self.domaindata = {}        # type: Dict[str, Dict]
-                                    # domainname -> domain-specific dict
+        # domainname -> domain-specific dict
+        self.domaindata: Dict[str, Dict] = {}
 
         # these map absolute path -> (docnames, unique filename)
-        self.images = FilenameUniqDict()    # type: FilenameUniqDict
-        self.dlfiles = DownloadFiles()      # type: DownloadFiles
-                                            # filename -> (set of docnames, destination)
+        self.images: FilenameUniqDict = FilenameUniqDict()
+        # filename -> (set of docnames, destination)
+        self.dlfiles: DownloadFiles = DownloadFiles()
 
         # the original URI for images
-        self.original_image_uri = {}  # type: Dict[str, str]
+        self.original_image_uri: Dict[str, str] = {}
 
         # temporary data storage while reading a document
-        self.temp_data = {}         # type: Dict[str, Any]
+        self.temp_data: Dict[str, Any] = {}
         # context for cross-references (e.g. current module or class)
         # this is similar to temp_data, but will for example be copied to
         # attributes of "any" cross references
-        self.ref_context = {}       # type: Dict[str, Any]
+        self.ref_context: Dict[str, Any] = {}
 
         # set up environment
         if app:
             self.setup(app)
+        else:
+            warnings.warn("The 'app' argument for BuildEnvironment() becomes required now.",
+                          RemovedInSphinx60Warning, stacklevel=2)
 
     def __getstate__(self) -> Dict:
         """Obtains serializable data for pickling."""
@@ -270,7 +274,7 @@ class BuildEnvironment:
         raise an exception if the user tries to use an environment with an
         incompatible versioning method.
         """
-        condition = None  # type: Union[bool, Callable]
+        condition: Union[bool, Callable]
         if callable(method):
             condition = method
         else:
@@ -313,35 +317,20 @@ class BuildEnvironment:
             domain.merge_domaindata(docnames, other.domaindata[domainname])
         self.events.emit('env-merge-info', self, docnames, other)
 
-    def path2doc(self, filename: str) -> str:
+    def path2doc(self, filename: str) -> Optional[str]:
         """Return the docname for the filename if the file is document.
 
         *filename* should be absolute or relative to the source directory.
         """
         return self.project.path2doc(filename)
 
-    def doc2path(self, docname: str, base: Union[bool, str] = True, suffix: str = None) -> str:
+    def doc2path(self, docname: str, base: bool = True) -> str:
         """Return the filename for the document name.
 
         If *base* is True, return absolute path under self.srcdir.
-        If *base* is None, return relative path to self.srcdir.
-        If *base* is a path string, return absolute path under that.
-        If *suffix* is not None, add it instead of config.source_suffix.
+        If *base* is False, return relative path to self.srcdir.
         """
-        if suffix:
-            warnings.warn('The suffix argument for doc2path() is deprecated.',
-                          RemovedInSphinx40Warning, stacklevel=2)
-        if base not in (True, False, None):
-            warnings.warn('The string style base argument for doc2path() is deprecated.',
-                          RemovedInSphinx40Warning, stacklevel=2)
-
-        pathname = self.project.doc2path(docname, base is True)
-        if suffix:
-            filename, _ = path.splitext(pathname)
-            pathname = filename + suffix
-        if base and base is not True:
-            pathname = path.join(base, pathname)  # type: ignore
-        return pathname
+        return self.project.doc2path(docname, base)
 
     def relfn2path(self, filename: str, docname: str = None) -> Tuple[str, str]:
         """Return paths to a file referenced from a document, relative to
@@ -401,8 +390,8 @@ class BuildEnvironment:
         # clear all files no longer present
         removed = set(self.all_docs) - self.found_docs
 
-        added = set()  # type: Set[str]
-        changed = set()  # type: Set[str]
+        added: Set[str] = set()
+        changed: Set[str] = set()
 
         if config_changed:
             # config values affect e.g. substitutions
@@ -410,21 +399,28 @@ class BuildEnvironment:
         else:
             for docname in self.found_docs:
                 if docname not in self.all_docs:
+                    logger.debug('[build target] added %r', docname)
                     added.add(docname)
                     continue
                 # if the doctree file is not there, rebuild
                 filename = path.join(self.doctreedir, docname + '.doctree')
                 if not path.isfile(filename):
+                    logger.debug('[build target] changed %r', docname)
                     changed.add(docname)
                     continue
                 # check the "reread always" list
                 if docname in self.reread_always:
+                    logger.debug('[build target] changed %r', docname)
                     changed.add(docname)
                     continue
                 # check the mtime of the document
                 mtime = self.all_docs[docname]
                 newmtime = path.getmtime(self.doc2path(docname))
                 if newmtime > mtime:
+                    logger.debug('[build target] outdated %r: %s -> %s',
+                                 docname,
+                                 datetime.utcfromtimestamp(mtime),
+                                 datetime.utcfromtimestamp(newmtime))
                     changed.add(docname)
                     continue
                 # finally, check the mtime of dependencies
@@ -447,7 +443,7 @@ class BuildEnvironment:
         return added, changed, removed
 
     def check_dependents(self, app: "Sphinx", already: Set[str]) -> Generator[str, None, None]:
-        to_rewrite = []  # type: List[str]
+        to_rewrite: List[str] = []
         for docnames in self.events.emit('env-get-updated', self):
             to_rewrite.extend(docnames)
         for docname in set(to_rewrite):
@@ -589,7 +585,7 @@ class BuildEnvironment:
         # allow custom references to be resolved
         self.events.emit('doctree-resolved', doctree, docname)
 
-    def collect_relations(self) -> Dict[str, List[str]]:
+    def collect_relations(self) -> Dict[str, List[Optional[str]]]:
         traversed = set()
 
         def traverse_toctree(parent: str, docname: str) -> Iterator[Tuple[str, str]]:
@@ -610,7 +606,7 @@ class BuildEnvironment:
                         traversed.add(subdocname)
 
         relations = {}
-        docnames = traverse_toctree(None, self.config.master_doc)
+        docnames = traverse_toctree(None, self.config.root_doc)
         prevdoc = None
         parent, docname = next(docnames)
         for nextparent, nextdoc in docnames:
@@ -628,7 +624,7 @@ class BuildEnvironment:
         included = set().union(*self.included.values())  # type: ignore
         for docname in sorted(self.all_docs):
             if docname not in self.files_to_rebuild:
-                if docname == self.config.master_doc:
+                if docname == self.config.root_doc:
                     # the master file is not included anywhere ;)
                     continue
                 if docname in included:
@@ -643,19 +639,3 @@ class BuildEnvironment:
         for domain in self.domains.values():
             domain.check_consistency()
         self.events.emit('env-check-consistency', self)
-
-    @property
-    def indexentries(self) -> Dict[str, List[Tuple[str, str, str, str, str]]]:
-        warnings.warn('env.indexentries() is deprecated. Please use IndexDomain instead.',
-                      RemovedInSphinx40Warning, stacklevel=2)
-        from sphinx.domains.index import IndexDomain
-        domain = cast(IndexDomain, self.get_domain('index'))
-        return domain.entries
-
-    @indexentries.setter
-    def indexentries(self, entries: Dict[str, List[Tuple[str, str, str, str, str]]]) -> None:
-        warnings.warn('env.indexentries() is deprecated. Please use IndexDomain instead.',
-                      RemovedInSphinx40Warning, stacklevel=2)
-        from sphinx.domains.index import IndexDomain
-        domain = cast(IndexDomain, self.get_domain('index'))
-        domain.data['entries'] = entries
