@@ -31,7 +31,7 @@ class IndexEntries:
                      _fixre: Pattern = re.compile(r'(.*) ([(][^()]*[)])')
                      ) -> List[Tuple[str, List[Tuple[str, Any]]]]:
         """Create the real index from the collected index entries."""
-        new = {}  # type: Dict[str, List]
+        new: Dict[str, List] = {}
 
         def add_entry(word: str, subword: str, main: str, link: bool = True,
                       dic: Dict = new, key: str = None) -> None:
@@ -107,12 +107,12 @@ class IndexEntries:
                 lckey = lckey[1:]
 
             if lckey[0:1].isalpha() or lckey.startswith('_'):
-                # put non-symbol characters at the folloing group (1)
+                # put non-symbol characters at the following group (1)
                 sortkey = (1, lckey)
             else:
                 # put symbols at the front of the index (0)
                 sortkey = (0, lckey)
-            # ensure a determinstic order *within* letters by also sorting on
+            # ensure a deterministic order *within* letters by also sorting on
             # the entry itself
             return (sortkey, entry[0])
         newlist = sorted(new.items(), key=keyfunc)
@@ -126,7 +126,7 @@ class IndexEntries:
             #     (in module foo)
             #     (in module bar)
             oldkey = ''
-            oldsubitems = None  # type: Dict[str, List]
+            oldsubitems: Dict[str, List] = None
             i = 0
             while i < len(newlist):
                 key, (targets, subitems, _key) = newlist[i]
