@@ -4,29 +4,25 @@
 
     A Base class for additional parsers.
 
-    :copyright: Copyright 2007-2020 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
 import warnings
-from typing import Any, Dict, List, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, Union
 
 import docutils.parsers
 import docutils.parsers.rst
 from docutils import nodes
 from docutils.parsers.rst import states
 from docutils.statemachine import StringList
+from docutils.transforms import Transform
 from docutils.transforms.universal import SmartQuotes
 
 from sphinx.deprecation import RemovedInSphinx50Warning
 from sphinx.util.rst import append_epilog, prepend_prolog
 
-if False:
-    # For type annotation
-    from typing import Type  # NOQA # for python3.5.1
-
-    from docutils.transforms import Transform  # NOQA
-
+if TYPE_CHECKING:
     from sphinx.application import Sphinx
 
 
@@ -36,7 +32,7 @@ class Parser(docutils.parsers.Parser):
     of ``docutils.parsers.Parser``.  Compared with ``docutils.parsers.Parser``, this class
     improves accessibility to Sphinx APIs.
 
-    The subclasses can access following objects and functions:
+    The subclasses can access the following objects and functions:
 
     self.app
         The application object (:class:`sphinx.application.Sphinx`)
@@ -47,7 +43,7 @@ class Parser(docutils.parsers.Parser):
     self.warn()
         Emit a warning. (Same as :meth:`sphinx.application.Sphinx.warn()`)
     self.info()
-        Emit a informational message. (Same as :meth:`sphinx.application.Sphinx.info()`)
+        Emit an info message. (Same as :meth:`sphinx.application.Sphinx.info()`)
 
     .. deprecated:: 1.6
        ``warn()`` and ``info()`` is deprecated.  Use :mod:`sphinx.util.logging` instead.
@@ -73,8 +69,9 @@ class Parser(docutils.parsers.Parser):
 class RSTParser(docutils.parsers.rst.Parser, Parser):
     """A reST parser for Sphinx."""
 
-    def get_transforms(self) -> List["Type[Transform]"]:
-        """Sphinx's reST parser replaces a transform class for smart-quotes by own's
+    def get_transforms(self) -> List[Type[Transform]]:
+        """
+        Sphinx's reST parser replaces a transform class for smart-quotes by its own
 
         refs: sphinx.io.SphinxStandaloneReader
         """
