@@ -10,24 +10,18 @@
 import html
 import pickle
 import re
-import warnings
 from importlib import import_module
 from os import path
-from typing import IO, Any, Dict, Iterable, List, Set, Tuple
+from typing import IO, Any, Dict, Iterable, List, Optional, Set, Tuple, Type
 
 from docutils import nodes
 from docutils.nodes import Node
 
 from sphinx import addnodes, package_dir
-from sphinx.deprecation import RemovedInSphinx40Warning
 from sphinx.environment import BuildEnvironment
 from sphinx.search.jssplitter import splitter_code
 from sphinx.util import jsdump
 
-if False:
-    # For type annotation
-    from typing import Type  # for python3.5.1
-
 
 class SearchLanguage:
     """
@@ -44,7 +38,7 @@ class SearchLanguage:
 
     .. attribute:: js_splitter_code
 
-       Return splitter funcion of JavaScript version.  The function should be
+       Return splitter function of JavaScript version.  The function should be
        named as ``splitQuery``.  And it should take a string and return list of
        strings.
 
@@ -59,11 +53,11 @@ class SearchLanguage:
        This class is used to preprocess search word which Sphinx HTML readers
        type, before searching index. Default implementation does nothing.
     """
-    lang = None                 # type: str
-    language_name = None        # type: str
-    stopwords = set()           # type: Set[str]
-    js_splitter_code = None     # type: str
-    js_stemmer_rawcode = None   # type: str
+    lang: str = None
+    language_name: str = None
+    stopwords: Set[str] = set()
+    js_splitter_code: str = None
+    js_stemmer_rawcode: str = None
     js_stemmer_code = """
 /**
  * Dummy stemmer for languages without stemming rules.
@@ -116,7 +110,7 @@ var Stemmer = function() {
             len(word) == 0 or not (
                 ((len(word) < 3) and (12353 < ord(word[0]) < 12436)) or
                 (ord(word[0]) < 256 and (
-                    len(word) < 3 or word in self.stopwords
+                    word in self.stopwords
                 ))))
 
 
@@ -126,11 +120,11 @@ from sphinx.search.en import SearchEnglish
 
 def parse_stop_word(source: str) -> Set[str]:
     """
-    parse snowball style word list like this:
+    Parse snowball style word list like this:
 
     * http://snowball.tartarus.org/algorithms/finnish/stop.txt
     """
-    result = set()  # type: Set[str]
+    result: Set[str] = set()
     for line in source.splitlines():
         line = line.split('|')[0]  # remove comment
         result.update(line.split())
@@ -138,7 +132,7 @@ def parse_stop_word(source: str) -> Set[str]:
 
 
 # maps language name to module.class or directly a class
-languages = {
+languages: Dict[str, Any] = {
     'da': 'sphinx.search.da.SearchDanish',
     'de': 'sphinx.search.de.SearchGerman',
     'en': SearchEnglish,
@@ -156,12 +150,12 @@ languages = {
     'sv': 'sphinx.search.sv.SearchSwedish',
     'tr': 'sphinx.search.tr.SearchTurkish',
     'zh': 'sphinx.search.zh.SearchChinese',
-}  # type: Dict[str, Any]
+}
 
 
 class _JavaScriptIndex:
     """
-    The search index as javascript file that calls a function
+    The search index as JavaScript file that calls a function
     on the documentation search object to register the index.
     """
 
@@ -195,15 +189,11 @@ class WordCollector(nodes.NodeVisitor):
 
     def __init__(self, document: nodes.document, lang: SearchLanguage) -> None:
         super().__init__(document)
-        self.found_words = []           # type: List[str]
-        self.found_title_words = []     # type: List[str]
+        self.found_words: List[str] = []
+        self.found_title_words: List[str] = []
         self.lang = lang
 
-    def is_meta_keywords(self, node: addnodes.meta, nodetype: Any = None) -> bool:
-        if nodetype is not None:
-            warnings.warn('"nodetype" argument for WordCollector.is_meta_keywords() '
-                          'is deprecated.', RemovedInSphinx40Warning, stacklevel=2)
-
+    def is_meta_keywords(self, node: addnodes.meta) -> bool:
         if isinstance(node, addnodes.meta) and node.get('name') == 'keywords':
             meta_lang = node.get('lang')
             if meta_lang is None:  # lang not specified
@@ -238,7 +228,7 @@ class WordCollector(nodes.NodeVisitor):
 
 class IndexBuilder:
     """
-    Helper class that creates a searchindex based on the doctrees
+    Helper class that creates a search index based on the doctrees
     passed to the `feed` method.
     """
     formats = {
@@ -248,29 +238,24 @@ class IndexBuilder:
 
     def __init__(self, env: BuildEnvironment, lang: str, options: Dict, scoring: str) -> None:
         self.env = env
-        self._titles = {}           # type: Dict[str, str]
-                                    # docname -> title
-        self._filenames = {}        # type: Dict[str, str]
-                                    # docname -> filename
-        self._mapping = {}          # type: Dict[str, Set[str]]
-                                    # stemmed word -> set(docname)
-        self._title_mapping = {}    # type: Dict[str, Set[str]]
-                                    # stemmed words in titles -> set(docname)
-        self._stem_cache = {}       # type: Dict[str, str]
-                                    # word -> stemmed word
-        self._objtypes = {}         # type: Dict[Tuple[str, str], int]
-                                    # objtype -> index
-        self._objnames = {}         # type: Dict[int, Tuple[str, str, str]]
-                                    # objtype index -> (domain, type, objname (localized))
-        lang_class = languages.get(lang)    # type: Type[SearchLanguage]
-                                            # add language-specific SearchLanguage instance
+        self._titles: Dict[str, str] = {}           # docname -> title
+        self._filenames: Dict[str, str] = {}        # docname -> filename
+        self._mapping: Dict[str, Set[str]] = {}     # stemmed word -> set(docname)
+        # stemmed words in titles -> set(docname)
+        self._title_mapping: Dict[str, Set[str]] = {}
+        self._stem_cache: Dict[str, str] = {}       # word -> stemmed word
+        self._objtypes: Dict[Tuple[str, str], int] = {}     # objtype -> index
+        # objtype index -> (domain, type, objname (localized))
+        self._objnames: Dict[int, Tuple[str, str, str]] = {}
+        # add language-specific SearchLanguage instance
+        lang_class: Type[SearchLanguage] = languages.get(lang)
 
         # fallback; try again with language-code
         if lang_class is None and '_' in lang:
             lang_class = languages.get(lang.split('_')[0])
 
         if lang_class is None:
-            self.lang = SearchEnglish(options)  # type: SearchLanguage
+            self.lang: SearchLanguage = SearchEnglish(options)
         elif isinstance(lang_class, str):
             module, classname = lang_class.rsplit('.', 1)
             lang_class = getattr(import_module(module), classname)
@@ -319,8 +304,8 @@ class IndexBuilder:
         format.dump(self.freeze(), stream)
 
     def get_objects(self, fn2index: Dict[str, int]
-                    ) -> Dict[str, Dict[str, Tuple[int, int, int, str]]]:
-        rv = {}  # type: Dict[str, Dict[str, Tuple[int, int, int, str]]]
+                    ) -> Dict[str, List[Tuple[int, int, int, str, str]]]:
+        rv: Dict[str, List[Tuple[int, int, int, str, str]]] = {}
         otypes = self._objtypes
         onames = self._objnames
         for domainname, domain in sorted(self.env.domains.items()):
@@ -333,7 +318,7 @@ class IndexBuilder:
                 fullname = html.escape(fullname)
                 dispname = html.escape(dispname)
                 prefix, _, name = dispname.rpartition('.')
-                pdict = rv.setdefault(prefix, {})
+                plist = rv.setdefault(prefix, [])
                 try:
                     typeindex = otypes[domainname, type]
                 except KeyError:
@@ -352,11 +337,11 @@ class IndexBuilder:
                     shortanchor = '-'
                 else:
                     shortanchor = anchor
-                pdict[name] = (fn2index[docname], typeindex, prio, shortanchor)
+                plist.append((fn2index[docname], typeindex, prio, shortanchor, name))
         return rv
 
     def get_terms(self, fn2index: Dict) -> Tuple[Dict[str, List[str]], Dict[str, List[str]]]:
-        rvs = {}, {}  # type: Tuple[Dict[str, List[str]], Dict[str, List[str]]]
+        rvs: Tuple[Dict[str, List[str]], Dict[str, List[str]]] = ({}, {})
         for rv, mapping in zip(rvs, (self._mapping, self._title_mapping)):
             for k, v in mapping.items():
                 if len(v) == 1:
@@ -455,7 +440,7 @@ class IndexBuilder:
         else:
             return []
 
-    def get_js_stemmer_rawcode(self) -> str:
+    def get_js_stemmer_rawcode(self) -> Optional[str]:
         return None
 
     def get_js_stemmer_code(self) -> str:
