@@ -4,7 +4,7 @@
 
     Theming support for HTML builders.
 
-    :copyright: Copyright 2007-2020 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
@@ -13,7 +13,7 @@ import os
 import shutil
 import tempfile
 from os import path
-from typing import Any, Dict, List
+from typing import TYPE_CHECKING, Any, Dict, List
 from zipfile import ZipFile
 
 import pkg_resources
@@ -24,8 +24,7 @@ from sphinx.locale import __
 from sphinx.util import logging
 from sphinx.util.osutil import ensuredir
 
-if False:
-    # For type annotation
+if TYPE_CHECKING:
     from sphinx.application import Sphinx
 
 
@@ -143,7 +142,7 @@ class Theme:
 
 
 def is_archived_theme(filename: str) -> bool:
-    """Check the specified file is an archived theme file or not."""
+    """Check whether the specified file is an archived theme file or not."""
     try:
         with ZipFile(filename) as f:
             return THEMECONF in f.namelist()
@@ -156,7 +155,7 @@ class HTMLThemeFactory:
 
     def __init__(self, app: "Sphinx") -> None:
         self.app = app
-        self.themes = app.html_themes
+        self.themes = app.registry.html_themes
         self.load_builtin_themes()
         if getattr(app.config, 'html_theme_path', None):
             self.load_additional_themes(app.config.html_theme_path)
@@ -176,11 +175,9 @@ class HTMLThemeFactory:
                 self.themes[name] = theme
 
     def load_extra_theme(self, name: str) -> None:
-        """Try to load a theme having specifed name."""
+        """Try to load a theme with the specified name."""
         if name == 'alabaster':
             self.load_alabaster_theme()
-        elif name == 'sphinx_rtd_theme':
-            self.load_sphinx_rtd_theme()
         else:
             self.load_external_theme(name)
 
@@ -190,7 +187,7 @@ class HTMLThemeFactory:
         self.themes['alabaster'] = path.join(alabaster.get_path(), 'alabaster')
 
     def load_sphinx_rtd_theme(self) -> None:
-        """Load sphinx_rtd_theme theme (if exists)."""
+        """Load sphinx_rtd_theme theme (if installed)."""
         try:
             import sphinx_rtd_theme
             theme_path = sphinx_rtd_theme.get_html_theme_path()
@@ -214,7 +211,7 @@ class HTMLThemeFactory:
 
     def find_themes(self, theme_path: str) -> Dict[str, str]:
         """Search themes from specified directory."""
-        themes = {}  # type: Dict[str, str]
+        themes: Dict[str, str] = {}
         if not path.isdir(theme_path):
             return themes
 
@@ -238,13 +235,13 @@ class HTMLThemeFactory:
         if name not in self.themes:
             self.load_extra_theme(name)
 
+        if name not in self.themes and name == 'sphinx_rtd_theme':
+            # sphinx_rtd_theme (< 0.2.5)  # RemovedInSphinx60Warning
+            logger.warning(__('sphinx_rtd_theme (< 0.3.0) found. '
+                              'It will not be available since Sphinx-6.0'))
+            self.load_sphinx_rtd_theme()
+
         if name not in self.themes:
-            if name == 'sphinx_rtd_theme':
-                raise ThemeError(__('sphinx_rtd_theme is no longer a hard dependency '
-                                    'since version 1.4.0. Please install it manually.'
-                                    '(pip install sphinx_rtd_theme)'))
-            else:
-                raise ThemeError(__('no theme named %r found '
-                                    '(missing theme.conf?)') % name)
+            raise ThemeError(__('no theme named %r found (missing theme.conf?)') % name)
 
         return Theme(name, self.themes[name], factory=self)
