@@ -8,7 +8,6 @@
     :license: BSD, see LICENSE for details.
 """
 
-import fnmatch
 import functools
 import hashlib
 import os
@@ -19,20 +18,17 @@ import tempfile
 import traceback
 import unicodedata
 import warnings
-from codecs import BOM_UTF8
-from collections import deque
 from datetime import datetime
 from importlib import import_module
 from os import path
 from time import mktime, strptime
-from typing import IO, Any, Callable, Dict, Iterable, Iterator, List, Pattern, Set, Tuple
+from typing import (IO, TYPE_CHECKING, Any, Callable, Dict, Iterable, Iterator, List, Optional,
+                    Pattern, Set, Tuple, Type)
 from urllib.parse import parse_qsl, quote_plus, urlencode, urlsplit, urlunsplit
 
-from sphinx.deprecation import RemovedInSphinx40Warning, RemovedInSphinx50Warning
-from sphinx.errors import (ExtensionError, FiletypeNotFoundError, PycodeError,
-                           SphinxParallelError)
+from sphinx.deprecation import RemovedInSphinx50Warning
+from sphinx.errors import ExtensionError, FiletypeNotFoundError, SphinxParallelError
 from sphinx.locale import __
-from sphinx.util import smartypants  # noqa
 from sphinx.util import logging
 from sphinx.util.console import bold, colorize, strip_colors, term_width_line  # type: ignore
 from sphinx.util.matching import patfilter  # noqa
@@ -41,21 +37,18 @@ from sphinx.util.nodes import (caption_ref_re, explicit_title_re,  # noqa
 # import other utilities; partly for backwards compatibility, so don't
 # prune unused ones indiscriminately
 from sphinx.util.osutil import (SEP, copyfile, copytimes, ensuredir, make_filename,  # noqa
-                                movefile, mtimes_of_files, os_path, relative_uri, walk)
+                                movefile, mtimes_of_files, os_path, relative_uri)
 from sphinx.util.typing import PathMatcher
 
-if False:
-    # For type annotation
-    from typing import Type  # for python3.5.1
-
+if TYPE_CHECKING:
     from sphinx.application import Sphinx
 
 
 logger = logging.getLogger(__name__)
 
 # Generally useful regular expressions.
-ws_re = re.compile(r'\s+')                      # type: Pattern
-url_re = re.compile(r'(?P<schema>.+)://.*')     # type: Pattern
+ws_re: Pattern = re.compile(r'\s+')
+url_re: Pattern = re.compile(r'(?P<schema>.+)://.*')
 
 
 # High-level utility functions.
@@ -66,7 +59,7 @@ def docname_join(basedocname: str, docname: str) -> str:
 
 
 def path_stabilize(filepath: str) -> str:
-    "normalize path separater and unicode string"
+    "Normalize path separator and unicode string"
     newpath = filepath.replace(os.path.sep, SEP)
     return unicodedata.normalize('NFC', newpath)
 
@@ -98,23 +91,6 @@ def get_matching_files(dirname: str,
             yield filename
 
 
-def get_matching_docs(dirname: str, suffixes: List[str],
-                      exclude_matchers: Tuple[PathMatcher, ...] = ()) -> Iterable[str]:
-    """Get all file names (without suffixes) matching a suffix in a directory,
-    recursively.
-
-    Exclude files and dirs matching a pattern in *exclude_patterns*.
-    """
-    warnings.warn('get_matching_docs() is now deprecated. Use get_matching_files() instead.',
-                  RemovedInSphinx40Warning, stacklevel=2)
-    suffixpatterns = ['*' + s for s in suffixes]
-    for filename in get_matching_files(dirname, exclude_matchers):
-        for suffixpattern in suffixpatterns:
-            if fnmatch.fnmatch(filename, suffixpattern):
-                yield filename[:-len(suffixpattern) + 1]
-                break
-
-
 def get_filetype(source_suffix: Dict[str, str], filename: str) -> str:
     for suffix, filetype in source_suffix.items():
         if filename.endswith(suffix):
@@ -131,7 +107,7 @@ class FilenameUniqDict(dict):
     appear in.  Used for images and downloadable files in the environment.
     """
     def __init__(self) -> None:
-        self._existing = set()  # type: Set[str]
+        self._existing: Set[str] = set()
 
     def add_file(self, docname: str, newfile: str) -> str:
         if newfile in self:
@@ -177,7 +153,7 @@ def md5(data=b'', **kwargs):
     """
 
     try:
-        return hashlib.md5(data, **kwargs)  # type: ignore
+        return hashlib.md5(data, **kwargs)
     except ValueError:
         return hashlib.md5(data, **kwargs, usedforsecurity=False)  # type: ignore
 
@@ -191,7 +167,7 @@ def sha1(data=b'', **kwargs):
     """
 
     try:
-        return hashlib.sha1(data, **kwargs)  # type: ignore
+        return hashlib.sha1(data, **kwargs)
     except ValueError:
         return hashlib.sha1(data, **kwargs, usedforsecurity=False)  # type: ignore
 
@@ -259,7 +235,7 @@ def save_traceback(app: "Sphinx") -> str:
                    platform.python_version(),
                    platform.python_implementation(),
                    docutils.__version__, docutils.__version_details__,
-                   jinja2.__version__,  # type: ignore
+                   jinja2.__version__,
                    last_msgs)).encode())
     if app is not None:
         for ext in app.extensions.values():
@@ -272,53 +248,6 @@ def save_traceback(app: "Sphinx") -> str:
     return path
 
 
-def get_module_source(modname: str) -> Tuple[str, str]:
-    """Try to find the source code for a module.
-
-    Can return ('file', 'filename') in which case the source is in the given
-    file, or ('string', 'source') which which case the source is the string.
-    """
-    warnings.warn('get_module_source() is deprecated.',
-                  RemovedInSphinx40Warning, stacklevel=2)
-    try:
-        mod = import_module(modname)
-    except Exception as err:
-        raise PycodeError('error importing %r' % modname, err) from err
-    filename = getattr(mod, '__file__', None)
-    loader = getattr(mod, '__loader__', None)
-    if loader and getattr(loader, 'get_filename', None):
-        try:
-            filename = loader.get_filename(modname)
-        except Exception as err:
-            raise PycodeError('error getting filename for %r' % filename, err) from err
-    if filename is None and loader:
-        try:
-            filename = loader.get_source(modname)
-            if filename:
-                return 'string', filename
-        except Exception as err:
-            raise PycodeError('error getting source for %r' % modname, err) from err
-    if filename is None:
-        raise PycodeError('no source found for module %r' % modname)
-    filename = path.normpath(path.abspath(filename))
-    lfilename = filename.lower()
-    if lfilename.endswith('.pyo') or lfilename.endswith('.pyc'):
-        filename = filename[:-1]
-        if not path.isfile(filename) and path.isfile(filename + 'w'):
-            filename += 'w'
-    elif not (lfilename.endswith('.py') or lfilename.endswith('.pyw')):
-        raise PycodeError('source is not a .py file: %r' % filename)
-    elif ('.egg' + os.path.sep) in filename:
-        pat = '(?<=\\.egg)' + re.escape(os.path.sep)
-        eggpath, _ = re.split(pat, filename, 1)
-        if path.isfile(eggpath):
-            return 'file', filename
-
-    if not path.isfile(filename):
-        raise PycodeError('source file is not present: %r' % filename)
-    return 'file', filename
-
-
 def get_full_modname(modname: str, attribute: str) -> str:
     if modname is None:
         # Prevents a TypeError: if the last getattr() call will return None
@@ -340,58 +269,6 @@ def get_full_modname(modname: str, attribute: str) -> str:
 _coding_re = re.compile(r'coding[:=]\s*([-\w.]+)')
 
 
-def detect_encoding(readline: Callable[[], bytes]) -> str:
-    """Like tokenize.detect_encoding() from Py3k, but a bit simplified."""
-    warnings.warn('sphinx.util.detect_encoding() is deprecated',
-                  RemovedInSphinx40Warning, stacklevel=2)
-
-    def read_or_stop() -> bytes:
-        try:
-            return readline()
-        except StopIteration:
-            return None
-
-    def get_normal_name(orig_enc: str) -> str:
-        """Imitates get_normal_name in tokenizer.c."""
-        # Only care about the first 12 characters.
-        enc = orig_enc[:12].lower().replace('_', '-')
-        if enc == 'utf-8' or enc.startswith('utf-8-'):
-            return 'utf-8'
-        if enc in ('latin-1', 'iso-8859-1', 'iso-latin-1') or \
-           enc.startswith(('latin-1-', 'iso-8859-1-', 'iso-latin-1-')):
-            return 'iso-8859-1'
-        return orig_enc
-
-    def find_cookie(line: bytes) -> str:
-        try:
-            line_string = line.decode('ascii')
-        except UnicodeDecodeError:
-            return None
-
-        matches = _coding_re.findall(line_string)
-        if not matches:
-            return None
-        return get_normal_name(matches[0])
-
-    default = sys.getdefaultencoding()
-    first = read_or_stop()
-    if first and first.startswith(BOM_UTF8):
-        first = first[3:]
-        default = 'utf-8-sig'
-    if not first:
-        return default
-    encoding = find_cookie(first)
-    if encoding:
-        return encoding
-    second = read_or_stop()
-    if not second:
-        return default
-    encoding = find_cookie(second)
-    if encoding:
-        return encoding
-    return default
-
-
 class UnicodeDecodeErrorHandler:
     """Custom error handler for open() that warns and replaces."""
 
@@ -463,7 +340,7 @@ def parselinenos(spec: str, total: int) -> List[int]:
 def force_decode(string: str, encoding: str) -> str:
     """Forcibly get a unicode string out of a bytestring."""
     warnings.warn('force_decode() is deprecated.',
-                  RemovedInSphinx40Warning, stacklevel=2)
+                  RemovedInSphinx50Warning, stacklevel=2)
     if isinstance(string, bytes):
         try:
             if encoding:
@@ -477,22 +354,6 @@ def force_decode(string: str, encoding: str) -> str:
     return string
 
 
-class attrdict(dict):
-    def __init__(self, *args: Any, **kwargs: Any) -> None:
-        super().__init__(*args, **kwargs)
-        warnings.warn('The attrdict class is deprecated.',
-                      RemovedInSphinx40Warning, stacklevel=2)
-
-    def __getattr__(self, key: str) -> str:
-        return self[key]
-
-    def __setattr__(self, key: str, val: str) -> None:
-        self[key] = val
-
-    def __delattr__(self, key: str) -> None:
-        del self[key]
-
-
 def rpartition(s: str, t: str) -> Tuple[str, str]:
     """Similar to str.rpartition from 2.5, but doesn't return the separator."""
     warnings.warn('rpartition() is now deprecated.', RemovedInSphinx50Warning, stacklevel=2)
@@ -535,48 +396,13 @@ def format_exception_cut_frames(x: int = 1) -> str:
     """Format an exception with traceback, but only the last x frames."""
     typ, val, tb = sys.exc_info()
     # res = ['Traceback (most recent call last):\n']
-    res = []  # type: List[str]
+    res: List[str] = []
     tbres = traceback.format_tb(tb)
     res += tbres[-x:]
     res += traceback.format_exception_only(typ, val)
     return ''.join(res)
 
 
-class PeekableIterator:
-    """
-    An iterator which wraps any iterable and makes it possible to peek to see
-    what's the next item.
-    """
-    def __init__(self, iterable: Iterable) -> None:
-        self.remaining = deque()  # type: deque
-        self._iterator = iter(iterable)
-        warnings.warn('PeekableIterator is deprecated.',
-                      RemovedInSphinx40Warning, stacklevel=2)
-
-    def __iter__(self) -> "PeekableIterator":
-        return self
-
-    def __next__(self) -> Any:
-        """Return the next item from the iterator."""
-        if self.remaining:
-            return self.remaining.popleft()
-        return next(self._iterator)
-
-    next = __next__  # Python 2 compatibility
-
-    def push(self, item: Any) -> None:
-        """Push the `item` on the internal stack, it will be returned on the
-        next :meth:`next` call.
-        """
-        self.remaining.append(item)
-
-    def peek(self) -> Any:
-        """Return the next item without changing the state of the iterator."""
-        item = next(self)
-        self.push(item)
-        return item
-
-
 def import_object(objname: str, source: str = None) -> Any:
     """Import python object by qualname."""
     try:
@@ -599,7 +425,7 @@ def import_object(objname: str, source: str = None) -> Any:
             raise ExtensionError('Could not import %s' % objname, exc) from exc
 
 
-def split_full_qualified_name(name: str) -> Tuple[str, str]:
+def split_full_qualified_name(name: str) -> Tuple[Optional[str], str]:
     """Split full qualified name to a pair of modname and qualname.
 
     A qualname is an abbreviation for "Qualified name" introduced at PEP-3155
@@ -609,7 +435,7 @@ def split_full_qualified_name(name: str) -> Tuple[str, str]:
     A "full" qualified name means a string containing both module name and
     qualified name.
 
-    .. note:: This function imports module actually to check the exisitence.
+    .. note:: This function actually imports the module to check its existence.
               Therefore you need to mock 3rd party modules if needed before
               calling this function.
     """
@@ -638,6 +464,14 @@ def encode_uri(uri: str) -> str:
     return urlunsplit(split)
 
 
+def isurl(url: str) -> bool:
+    """Check *url* is URL or not."""
+    if url and '://' in url:
+        return True
+    else:
+        return False
+
+
 def display_chunk(chunk: Any) -> str:
     if isinstance(chunk, (list, tuple)):
         if len(chunk) == 1:
@@ -693,7 +527,7 @@ class progress_message:
     def __enter__(self) -> None:
         logger.info(bold(self.message + '... '), nonl=True)
 
-    def __exit__(self, exc_type: "Type[Exception]", exc_value: Exception, traceback: Any) -> bool:  # NOQA
+    def __exit__(self, exc_type: Type[Exception], exc_value: Exception, traceback: Any) -> bool:  # NOQA
         if isinstance(exc_value, SkipProgressMessage):
             logger.info(__('skipped'))
             if exc_value.args:
