@@ -4,37 +4,36 @@
 
     Builder superclass for all builders.
 
-    :copyright: Copyright 2007-2020 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
-import gettext
+
 import os
 import re
-import warnings
-from collections import namedtuple
 from datetime import datetime, timezone
 from os import path
-from typing import Callable, Generator, List, Set, Tuple
+from typing import TYPE_CHECKING, Callable, Generator, List, NamedTuple, Optional, Tuple, Union
 
 import babel.dates
 from babel.messages.mofile import write_mo
 from babel.messages.pofile import read_po
 
-from sphinx.deprecation import RemovedInSphinx40Warning
 from sphinx.errors import SphinxError
 from sphinx.locale import __
 from sphinx.util import logging
-from sphinx.util.matching import Matcher
 from sphinx.util.osutil import SEP, canon_path, relpath
 
-if False:
-    # For type annotation
+if TYPE_CHECKING:
     from sphinx.environment import BuildEnvironment
 
 
 logger = logging.getLogger(__name__)
 
-LocaleFileInfoBase = namedtuple('CatalogInfo', 'base_dir,domain,charset')
+
+class LocaleFileInfoBase(NamedTuple):
+    base_dir: str
+    domain: str
+    charset: str
 
 
 class CatalogInfo(LocaleFileInfoBase):
@@ -60,7 +59,7 @@ class CatalogInfo(LocaleFileInfoBase):
             not path.exists(self.mo_path) or
             path.getmtime(self.mo_path) < path.getmtime(self.po_path))
 
-    def write_mo(self, locale: str) -> None:
+    def write_mo(self, locale: str, use_fuzzy: bool = False) -> None:
         with open(self.po_path, encoding=self.charset) as file_po:
             try:
                 po = read_po(file_po, locale)
@@ -70,7 +69,7 @@ class CatalogInfo(LocaleFileInfoBase):
 
         with open(self.mo_path, 'wb') as file_mo:
             try:
-                write_mo(file_mo, po)
+                write_mo(file_mo, po, use_fuzzy)
             except Exception as exc:
                 logger.warning(__('writing error: %s, %s'), self.mo_path, exc)
 
@@ -92,8 +91,11 @@ class CatalogRepository:
 
         for locale_dir in self._locale_dirs:
             locale_dir = path.join(self.basedir, locale_dir)
-            if path.exists(path.join(locale_dir, self.language, 'LC_MESSAGES')):
+            locale_path = path.join(locale_dir, self.language, 'LC_MESSAGES')
+            if path.exists(locale_path):
                 yield locale_dir
+            else:
+                logger.verbose(__('locale_dir %s does not exists'), locale_path)
 
     @property
     def pofiles(self) -> Generator[Tuple[str, str], None, None]:
@@ -117,89 +119,17 @@ class CatalogRepository:
             yield CatalogInfo(basedir, domain, self.encoding)
 
 
-def find_catalog(docname: str, compaction: bool) -> str:
-    warnings.warn('find_catalog() is deprecated.',
-                  RemovedInSphinx40Warning, stacklevel=2)
-    if compaction:
-        ret = docname.split(SEP, 1)[0]
-    else:
-        ret = docname
-
-    return ret
-
-
-def docname_to_domain(docname: str, compation: bool) -> str:
+def docname_to_domain(docname: str, compaction: Union[bool, str]) -> str:
     """Convert docname to domain for catalogs."""
-    if compation:
+    if isinstance(compaction, str):
+        return compaction
+    if compaction:
         return docname.split(SEP, 1)[0]
     else:
         return docname
 
 
-def find_catalog_files(docname: str, srcdir: str, locale_dirs: List[str],
-                       lang: str, compaction: bool) -> List[str]:
-    warnings.warn('find_catalog_files() is deprecated.',
-                  RemovedInSphinx40Warning, stacklevel=2)
-    if not(lang and locale_dirs):
-        return []
-
-    domain = find_catalog(docname, compaction)
-    files = [gettext.find(domain, path.join(srcdir, dir_), [lang])
-             for dir_ in locale_dirs]
-    files = [relpath(f, srcdir) for f in files if f]
-    return files
-
-
-def find_catalog_source_files(locale_dirs: List[str], locale: str, domains: List[str] = None,
-                              charset: str = 'utf-8', force_all: bool = False,
-                              excluded: Matcher = Matcher([])) -> Set[CatalogInfo]:
-    """
-    :param list locale_dirs:
-       list of path as `['locale_dir1', 'locale_dir2', ...]` to find
-       translation catalogs. Each path contains a structure such as
-       `<locale>/LC_MESSAGES/domain.po`.
-    :param str locale: a language as `'en'`
-    :param list domains: list of domain names to get. If empty list or None
-       is specified, get all domain names. default is None.
-    :param boolean force_all:
-       Set True if you want to get all catalogs rather than updated catalogs.
-       default is False.
-    :return: [CatalogInfo(), ...]
-    """
-    warnings.warn('find_catalog_source_files() is deprecated.',
-                  RemovedInSphinx40Warning, stacklevel=2)
-
-    catalogs = set()  # type: Set[CatalogInfo]
-
-    if not locale:
-        return catalogs  # locale is not specified
-
-    for locale_dir in locale_dirs:
-        if not locale_dir:
-            continue  # skip system locale directory
-
-        base_dir = path.join(locale_dir, locale, 'LC_MESSAGES')
-
-        if not path.exists(base_dir):
-            continue  # locale path is not found
-
-        for dirpath, dirnames, filenames in os.walk(base_dir, followlinks=True):
-            filenames = [f for f in filenames if f.endswith('.po')]
-            for filename in filenames:
-                if excluded(path.join(relpath(dirpath, base_dir), filename)):
-                    continue
-                base = path.splitext(filename)[0]
-                domain = relpath(path.join(dirpath, base), base_dir).replace(path.sep, SEP)
-                if domains and domain not in domains:
-                    continue
-                cat = CatalogInfo(base_dir, domain, charset)
-                if force_all or cat.is_outdated():
-                    catalogs.add(cat)
-
-    return catalogs
-
-
-# date_format mappings: ustrftime() to bable.dates.format_datetime()
+# date_format mappings: ustrftime() to babel.dates.format_datetime()
 date_format_mappings = {
     '%a':  'EEE',     # Weekday as locale’s abbreviated name.
     '%A':  'EEEE',    # Weekday as locale’s full name.
@@ -234,14 +164,16 @@ date_format_mappings = {
     '%X':  'medium',  # Locale’s appropriate time representation.
     '%y':  'YY',      # Year without century as a zero-padded decimal number.
     '%Y':  'yyyy',    # Year with century as a decimal number.
-    '%Z':  'zzzz',    # Time zone name (no characters if no time zone exists).
+    '%Z':  'zzz',     # Time zone name (no characters if no time zone exists).
+    '%z':  'ZZZ',     # UTC offset in the form ±HHMM[SS[.ffffff]]
+                      # (empty string if the object is naive).
     '%%':  '%',
 }
 
 date_format_re = re.compile('(%s)' % '|'.join(date_format_mappings))
 
 
-def babel_format_date(date: datetime, format: str, locale: str,
+def babel_format_date(date: datetime, format: str, locale: Optional[str],
                       formatter: Callable = babel.dates.format_date) -> str:
     if locale is None:
         locale = 'en'
@@ -262,7 +194,7 @@ def babel_format_date(date: datetime, format: str, locale: str,
         return format
 
 
-def format_date(format: str, date: datetime = None, language: str = None) -> str:
+def format_date(format: str, date: datetime = None, language: Optional[str] = None) -> str:
     if date is None:
         # If time is not specified, try to use $SOURCE_DATE_EPOCH variable
         # See https://wiki.debian.org/ReproducibleBuilds/TimestampsProposal
