@@ -14,7 +14,7 @@ import sys
 import time
 import traceback
 from math import sqrt
-from typing import Any, Callable, Dict, List, Sequence
+from typing import Any, Callable, Dict, List, Optional, Sequence
 
 try:
     import multiprocessing
@@ -60,15 +60,15 @@ class ParallelTasks:
     def __init__(self, nproc: int) -> None:
         self.nproc = nproc
         # (optional) function performed by each task on the result of main task
-        self._result_funcs = {}  # type: Dict[int, Callable]
+        self._result_funcs: Dict[int, Callable] = {}
         # task arguments
-        self._args = {}  # type: Dict[int, List[Any]]
+        self._args: Dict[int, Optional[List[Any]]] = {}
         # list of subprocesses (both started and waiting)
-        self._procs = {}  # type: Dict[int, multiprocessing.Process]
+        self._procs: Dict[int, multiprocessing.Process] = {}
         # list of receiving pipe connections of running subprocesses
-        self._precvs = {}  # type: Dict[int, Any]
+        self._precvs: Dict[int, Any] = {}
         # list of receiving pipe connections of waiting subprocesses
-        self._precvsWaiting = {}  # type: Dict[int, Any]
+        self._precvsWaiting: Dict[int, Any] = {}
         # number of working subprocesses
         self._pworking = 0
         # task number of each subprocess
@@ -103,10 +103,25 @@ class ParallelTasks:
         self._join_one()
 
     def join(self) -> None:
-        while self._pworking:
-            self._join_one()
+        try:
+            while self._pworking:
+                if not self._join_one():
+                    time.sleep(0.02)
+        except Exception:
+            # shutdown other child processes on failure
+            self.terminate()
+            raise
 
-    def _join_one(self) -> None:
+    def terminate(self) -> None:
+        for tid in list(self._precvs):
+            self._procs[tid].terminate()
+            self._result_funcs.pop(tid)
+            self._procs.pop(tid)
+            self._precvs.pop(tid)
+            self._pworking -= 1
+
+    def _join_one(self) -> bool:
+        joined_any = False
         for tid, pipe in self._precvs.items():
             if pipe.poll():
                 exc, logs, result = pipe.recv()
@@ -118,15 +133,17 @@ class ParallelTasks:
                 self._procs[tid].join()
                 self._precvs.pop(tid)
                 self._pworking -= 1
+                joined_any = True
                 break
-        else:
-            time.sleep(0.02)
+
         while self._precvsWaiting and self._pworking < self.nproc:
             newtid, newprecv = self._precvsWaiting.popitem()
             self._precvs[newtid] = newprecv
             self._procs[newtid].start()
             self._pworking += 1
 
+        return joined_any
+
 
 def make_chunks(arguments: Sequence[str], nproc: int, maxbatch: int = 10) -> List[Any]:
     # determine how many documents to read in one go
