@@ -8,6 +8,10 @@ def func():
 async def coroutinefunc():
     pass
 
+
+async def asyncgenerator():
+    yield
+
 partial_func = partial(func)
 partial_coroutinefunc = partial(coroutinefunc)
 
