@@ -1,5 +1,4 @@
-from typing import TypeVar, Generic
-
+from typing import Generic, TypeVar
 
 T = TypeVar('T')
 
