@@ -1,4 +1,4 @@
-master_doc = 'links'
+root_doc = 'links'
 source_suffix = '.txt'
 exclude_patterns = ['_build']
 linkcheck_anchors = True
