@@ -1,7 +1,4 @@
-# -*- coding: utf-8 -*-
-
-# -*- coding: utf-8 -*-
-from setuptools import setup, find_packages
+from setuptools import find_packages, setup
 
 setup(
     name='test-theme',
