@@ -8,6 +8,7 @@
     :license: BSD, see LICENSE for details.
 """
 
+import itertools
 import re
 import zlib
 
@@ -137,9 +138,17 @@ def test_domain_cpp_ast_fundamental_types():
             if t == "std::nullptr_t":
                 id = "NSt9nullptr_tE"
             return "1f%s" % id
+        id1 = makeIdV1()
+        id2 = makeIdV2()
         input = "void f(%s arg)" % t.replace(' ', '  ')
         output = "void f(%s arg)" % t
-        check("function", input, {1: makeIdV1(), 2: makeIdV2()}, output=output)
+        check("function", input, {1: id1, 2: id2}, output=output)
+        if ' ' in t:
+            # try permutations of all components
+            tcs = t.split()
+            for p in itertools.permutations(tcs):
+                input = "void f(%s arg)" % ' '.join(p)
+                check("function", input, {1: id1, 2: id2})
 
 
 def test_domain_cpp_ast_expressions():
