@@ -18,8 +18,10 @@ from docutils import nodes
 from sphinx import addnodes
 from sphinx.addnodes import (desc, desc_addname, desc_annotation, desc_content, desc_name,
                              desc_optional, desc_parameter, desc_parameterlist, desc_returns,
-                             desc_sig_name, desc_sig_operator, desc_sig_punctuation,
-                             desc_signature, pending_xref)
+                             desc_sig_keyword, desc_sig_literal_number,
+                             desc_sig_literal_string, desc_sig_name, desc_sig_operator,
+                             desc_sig_punctuation, desc_sig_space, desc_signature,
+                             pending_xref)
 from sphinx.domains import IndexEntry
 from sphinx.domains.python import (PythonDomain, PythonModuleIndex, _parse_annotation,
                                    _pseudo_parse_arglist, py_sig_re)
@@ -290,7 +292,8 @@ def test_parse_annotation(app):
     assert_node(doctree, ([pending_xref, "Tuple"],
                           [desc_sig_punctuation, "["],
                           [pending_xref, "int"],
-                          [desc_sig_punctuation, ", "],
+                          [desc_sig_punctuation, ","],
+                          desc_sig_space,
                           [pending_xref, "int"],
                           [desc_sig_punctuation, "]"]))
 
@@ -305,19 +308,23 @@ def test_parse_annotation(app):
     assert_node(doctree, ([pending_xref, "Tuple"],
                           [desc_sig_punctuation, "["],
                           [pending_xref, "int"],
-                          [desc_sig_punctuation, ", "],
+                          [desc_sig_punctuation, ","],
+                          desc_sig_space,
                           [desc_sig_punctuation, "..."],
                           [desc_sig_punctuation, "]"]))
 
     doctree = _parse_annotation("Callable[[int, int], int]", app.env)
+    print(doctree)
     assert_node(doctree, ([pending_xref, "Callable"],
                           [desc_sig_punctuation, "["],
                           [desc_sig_punctuation, "["],
                           [pending_xref, "int"],
-                          [desc_sig_punctuation, ", "],
+                          [desc_sig_punctuation, ","],
+                          desc_sig_space,
                           [pending_xref, "int"],
                           [desc_sig_punctuation, "]"],
-                          [desc_sig_punctuation, ", "],
+                          [desc_sig_punctuation, ","],
+                          desc_sig_space,
                           [pending_xref, "int"],
                           [desc_sig_punctuation, "]"]))
 
@@ -326,7 +333,8 @@ def test_parse_annotation(app):
                           [desc_sig_punctuation, "["],
                           [desc_sig_punctuation, "["],
                           [desc_sig_punctuation, "]"],
-                          [desc_sig_punctuation, ", "],
+                          [desc_sig_punctuation, ","],
+                          desc_sig_space,
                           [pending_xref, "int"],
                           [desc_sig_punctuation, "]"]))
 
@@ -347,19 +355,22 @@ def test_parse_annotation_Literal(app):
     doctree = _parse_annotation("Literal[True, False]", app.env)
     assert_node(doctree, ([pending_xref, "Literal"],
                           [desc_sig_punctuation, "["],
-                          "True",
-                          [desc_sig_punctuation, ", "],
-                          "False",
+                          [desc_sig_keyword, "True"],
+                          [desc_sig_punctuation, ","],
+                          desc_sig_space,
+                          [desc_sig_keyword, "False"],
                           [desc_sig_punctuation, "]"]))
 
     doctree = _parse_annotation("typing.Literal[0, 1, 'abc']", app.env)
     assert_node(doctree, ([pending_xref, "typing.Literal"],
                           [desc_sig_punctuation, "["],
-                          "0",
-                          [desc_sig_punctuation, ", "],
-                          "1",
-                          [desc_sig_punctuation, ", "],
-                          "'abc'",
+                          [desc_sig_literal_number, "0"],
+                          [desc_sig_punctuation, ","],
+                          desc_sig_space,
+                          [desc_sig_literal_number, "1"],
+                          [desc_sig_punctuation, ","],
+                          desc_sig_space,
+                          [desc_sig_literal_string, "'abc'"],
                           [desc_sig_punctuation, "]"]))
 
 
@@ -376,7 +387,7 @@ def test_pyfunction_signature(app):
     assert_node(doctree[1][0][1],
                 [desc_parameterlist, desc_parameter, ([desc_sig_name, "name"],
                                                       [desc_sig_punctuation, ":"],
-                                                      " ",
+                                                      desc_sig_space,
                                                       [nodes.inline, pending_xref, "str"])])
 
 
@@ -394,7 +405,7 @@ def test_pyfunction_signature_full(app):
     assert_node(doctree[1][0][1],
                 [desc_parameterlist, ([desc_parameter, ([desc_sig_name, "a"],
                                                         [desc_sig_punctuation, ":"],
-                                                        " ",
+                                                        desc_sig_space,
                                                         [desc_sig_name, pending_xref, "str"])],
                                       [desc_parameter, ([desc_sig_name, "b"],
                                                         [desc_sig_operator, "="],
@@ -402,28 +413,28 @@ def test_pyfunction_signature_full(app):
                                       [desc_parameter, ([desc_sig_operator, "*"],
                                                         [desc_sig_name, "args"],
                                                         [desc_sig_punctuation, ":"],
-                                                        " ",
+                                                        desc_sig_space,
                                                         [desc_sig_name, pending_xref, "str"])],
                                       [desc_parameter, ([desc_sig_name, "c"],
                                                         [desc_sig_punctuation, ":"],
-                                                        " ",
+                                                        desc_sig_space,
                                                         [desc_sig_name, pending_xref, "bool"],
-                                                        " ",
+                                                        desc_sig_space,
                                                         [desc_sig_operator, "="],
-                                                        " ",
+                                                        desc_sig_space,
                                                         [nodes.inline, "True"])],
                                       [desc_parameter, ([desc_sig_name, "d"],
                                                         [desc_sig_punctuation, ":"],
-                                                        " ",
+                                                        desc_sig_space,
                                                         [desc_sig_name, pending_xref, "tuple"],
-                                                        " ",
+                                                        desc_sig_space,
                                                         [desc_sig_operator, "="],
-                                                        " ",
+                                                        desc_sig_space,
                                                         [nodes.inline, "(1, 2)"])],
                                       [desc_parameter, ([desc_sig_operator, "**"],
                                                         [desc_sig_name, "kwargs"],
                                                         [desc_sig_punctuation, ":"],
-                                                        " ",
+                                                        desc_sig_space,
                                                         [desc_sig_name, pending_xref, "str"])])])
 
 
@@ -482,11 +493,11 @@ def test_pyfunction_with_union_type_operator(app):
     assert_node(doctree[1][0][1],
                 [desc_parameterlist, ([desc_parameter, ([desc_sig_name, "age"],
                                                         [desc_sig_punctuation, ":"],
-                                                        " ",
+                                                        desc_sig_space,
                                                         [desc_sig_name, ([pending_xref, "int"],
-                                                                         " ",
+                                                                         desc_sig_space,
                                                                          [desc_sig_punctuation, "|"],
-                                                                         " ",
+                                                                         desc_sig_space,
                                                                          [pending_xref, "None"])])])])
 
 
@@ -501,16 +512,16 @@ def test_optional_pyfunction_signature(app):
     assert_node(doctree[1], addnodes.desc, desctype="function",
                 domain="py", objtype="function", noindex=False)
     assert_node(doctree[1][0][1],
-                ([desc_parameter, "source"],
-                 [desc_optional, ([desc_parameter, "filename"],
-                                  [desc_optional, desc_parameter, "symbol"])]))
+                ([desc_parameter, ([desc_sig_name, "source"])],
+                 [desc_optional, ([desc_parameter, ([desc_sig_name, "filename"])],
+                                  [desc_optional, desc_parameter, ([desc_sig_name, "symbol"])])]))
 
 
 def test_pyexception_signature(app):
     text = ".. py:exception:: builtins.IOError"
     doctree = restructuredtext.parse(app, text)
     assert_node(doctree, (addnodes.index,
-                          [desc, ([desc_signature, ([desc_annotation, "exception "],
+                          [desc, ([desc_signature, ([desc_annotation, ('exception', desc_sig_space)],
                                                     [desc_addname, "builtins."],
                                                     [desc_name, "IOError"])],
                                   desc_content)]))
@@ -525,9 +536,15 @@ def test_pydata_signature(app):
     doctree = restructuredtext.parse(app, text)
     assert_node(doctree, (addnodes.index,
                           [desc, ([desc_signature, ([desc_name, "version"],
-                                                    [desc_annotation, (": ",
+                                                    [desc_annotation, ([desc_sig_punctuation, ':'],
+                                                                       desc_sig_space,
                                                                        [pending_xref, "int"])],
-                                                    [desc_annotation, " = 1"])],
+                                                    [desc_annotation, (
+                                                        desc_sig_space,
+                                                        [desc_sig_punctuation, '='],
+                                                        desc_sig_space,
+                                                        "1")]
+                                                    )],
                                   desc_content)]))
     assert_node(doctree[1], addnodes.desc, desctype="data",
                 domain="py", objtype="data", noindex=False)
@@ -539,7 +556,8 @@ def test_pydata_signature_old(app):
     doctree = restructuredtext.parse(app, text)
     assert_node(doctree, (addnodes.index,
                           [desc, ([desc_signature, ([desc_name, "version"],
-                                                    [desc_annotation, " = 1"])],
+                                                    [desc_annotation, (desc_sig_space,
+                                                                       "= 1")])],
                                   desc_content)]))
     assert_node(doctree[1], addnodes.desc, desctype="data",
                 domain="py", objtype="data", noindex=False)
@@ -551,11 +569,12 @@ def test_pydata_with_union_type_operator(app):
     doctree = restructuredtext.parse(app, text)
     assert_node(doctree[1][0],
                 ([desc_name, "version"],
-                 [desc_annotation, (": ",
+                 [desc_annotation, ([desc_sig_punctuation, ':'],
+                                    desc_sig_space,
                                     [pending_xref, "int"],
-                                    " ",
+                                    desc_sig_space,
                                     [desc_sig_punctuation, "|"],
-                                    " ",
+                                    desc_sig_space,
                                     [pending_xref, "str"])]))
 
 
@@ -566,7 +585,7 @@ def test_pyobject_prefix(app):
             "   .. py:method:: FooBar.say")
     doctree = restructuredtext.parse(app, text)
     assert_node(doctree, (addnodes.index,
-                          [desc, ([desc_signature, ([desc_annotation, "class "],
+                          [desc, ([desc_signature, ([desc_annotation, ('class', desc_sig_space)],
                                                     [desc_name, "Foo"])],
                                   [desc_content, (addnodes.index,
                                                   desc,
@@ -587,10 +606,11 @@ def test_pydata(app):
                           addnodes.index,
                           [desc, ([desc_signature, ([desc_addname, "example."],
                                                     [desc_name, "var"],
-                                                    [desc_annotation, (": ",
+                                                    [desc_annotation, ([desc_sig_punctuation, ':'],
+                                                                       desc_sig_space,
                                                                        [pending_xref, "int"])])],
                                   [desc_content, ()])]))
-    assert_node(doctree[3][0][2][1], pending_xref, **{"py:module": "example"})
+    assert_node(doctree[3][0][2][2], pending_xref, **{"py:module": "example"})
     assert 'example.var' in domain.objects
     assert domain.objects['example.var'] == ('index', 'example.var', 'data', False)
 
@@ -609,7 +629,8 @@ def test_pyfunction(app):
                           nodes.target,
                           addnodes.index,
                           addnodes.index,
-                          [desc, ([desc_signature, ([desc_annotation, "async "],
+                          [desc, ([desc_signature, ([desc_annotation, ([desc_sig_keyword, 'async'],
+                                                                       desc_sig_space)],
                                                     [desc_addname, "example."],
                                                     [desc_name, "func2"],
                                                     [desc_parameterlist, ()])],
@@ -634,11 +655,14 @@ def test_pyclass_options(app):
     domain = app.env.get_domain('py')
     doctree = restructuredtext.parse(app, text)
     assert_node(doctree, (addnodes.index,
-                          [desc, ([desc_signature, ([desc_annotation, "class "],
+                          [desc, ([desc_signature, ([desc_annotation, ("class", desc_sig_space)],
                                                     [desc_name, "Class1"])],
                                   [desc_content, ()])],
                           addnodes.index,
-                          [desc, ([desc_signature, ([desc_annotation, "final class "],
+                          [desc, ([desc_signature, ([desc_annotation, ("final",
+                                                                       desc_sig_space,
+                                                                       "class",
+                                                                       desc_sig_space)],
                                                     [desc_name, "Class2"])],
                                   [desc_content, ()])]))
 
@@ -674,7 +698,7 @@ def test_pymethod_options(app):
     domain = app.env.get_domain('py')
     doctree = restructuredtext.parse(app, text)
     assert_node(doctree, (addnodes.index,
-                          [desc, ([desc_signature, ([desc_annotation, "class "],
+                          [desc, ([desc_signature, ([desc_annotation, ("class", desc_sig_space)],
                                                     [desc_name, "Class"])],
                                   [desc_content, (addnodes.index,
                                                   desc,
@@ -703,7 +727,7 @@ def test_pymethod_options(app):
     # :classmethod:
     assert_node(doctree[1][1][2], addnodes.index,
                 entries=[('single', 'meth2() (Class class method)', 'Class.meth2', '', None)])
-    assert_node(doctree[1][1][3], ([desc_signature, ([desc_annotation, "classmethod "],
+    assert_node(doctree[1][1][3], ([desc_signature, ([desc_annotation, ("classmethod", desc_sig_space)],
                                                      [desc_name, "meth2"],
                                                      [desc_parameterlist, ()])],
                                    [desc_content, ()]))
@@ -713,7 +737,7 @@ def test_pymethod_options(app):
     # :staticmethod:
     assert_node(doctree[1][1][4], addnodes.index,
                 entries=[('single', 'meth3() (Class static method)', 'Class.meth3', '', None)])
-    assert_node(doctree[1][1][5], ([desc_signature, ([desc_annotation, "static "],
+    assert_node(doctree[1][1][5], ([desc_signature, ([desc_annotation, ("static", desc_sig_space)],
                                                      [desc_name, "meth3"],
                                                      [desc_parameterlist, ()])],
                                    [desc_content, ()]))
@@ -723,7 +747,7 @@ def test_pymethod_options(app):
     # :async:
     assert_node(doctree[1][1][6], addnodes.index,
                 entries=[('single', 'meth4() (Class method)', 'Class.meth4', '', None)])
-    assert_node(doctree[1][1][7], ([desc_signature, ([desc_annotation, "async "],
+    assert_node(doctree[1][1][7], ([desc_signature, ([desc_annotation, ("async", desc_sig_space)],
                                                      [desc_name, "meth4"],
                                                      [desc_parameterlist, ()])],
                                    [desc_content, ()]))
@@ -732,8 +756,8 @@ def test_pymethod_options(app):
 
     # :property:
     assert_node(doctree[1][1][8], addnodes.index,
-                entries=[('single', 'meth5() (Class property)', 'Class.meth5', '', None)])
-    assert_node(doctree[1][1][9], ([desc_signature, ([desc_annotation, "property "],
+                entries=[('single', 'meth5 (Class property)', 'Class.meth5', '', None)])
+    assert_node(doctree[1][1][9], ([desc_signature, ([desc_annotation, ("property", desc_sig_space)],
                                                      [desc_name, "meth5"])],
                                    [desc_content, ()]))
     assert 'Class.meth5' in domain.objects
@@ -742,7 +766,7 @@ def test_pymethod_options(app):
     # :abstractmethod:
     assert_node(doctree[1][1][10], addnodes.index,
                 entries=[('single', 'meth6() (Class method)', 'Class.meth6', '', None)])
-    assert_node(doctree[1][1][11], ([desc_signature, ([desc_annotation, "abstract "],
+    assert_node(doctree[1][1][11], ([desc_signature, ([desc_annotation, ("abstract", desc_sig_space)],
                                                       [desc_name, "meth6"],
                                                       [desc_parameterlist, ()])],
                                     [desc_content, ()]))
@@ -752,7 +776,7 @@ def test_pymethod_options(app):
     # :final:
     assert_node(doctree[1][1][12], addnodes.index,
                 entries=[('single', 'meth7() (Class method)', 'Class.meth7', '', None)])
-    assert_node(doctree[1][1][13], ([desc_signature, ([desc_annotation, "final "],
+    assert_node(doctree[1][1][13], ([desc_signature, ([desc_annotation, ("final", desc_sig_space)],
                                                       [desc_name, "meth7"],
                                                       [desc_parameterlist, ()])],
                                     [desc_content, ()]))
@@ -767,13 +791,13 @@ def test_pyclassmethod(app):
     domain = app.env.get_domain('py')
     doctree = restructuredtext.parse(app, text)
     assert_node(doctree, (addnodes.index,
-                          [desc, ([desc_signature, ([desc_annotation, "class "],
+                          [desc, ([desc_signature, ([desc_annotation, ("class", desc_sig_space)],
                                                     [desc_name, "Class"])],
                                   [desc_content, (addnodes.index,
                                                   desc)])]))
     assert_node(doctree[1][1][0], addnodes.index,
                 entries=[('single', 'meth() (Class class method)', 'Class.meth', '', None)])
-    assert_node(doctree[1][1][1], ([desc_signature, ([desc_annotation, "classmethod "],
+    assert_node(doctree[1][1][1], ([desc_signature, ([desc_annotation, ("classmethod", desc_sig_space)],
                                                      [desc_name, "meth"],
                                                      [desc_parameterlist, ()])],
                                    [desc_content, ()]))
@@ -788,13 +812,13 @@ def test_pystaticmethod(app):
     domain = app.env.get_domain('py')
     doctree = restructuredtext.parse(app, text)
     assert_node(doctree, (addnodes.index,
-                          [desc, ([desc_signature, ([desc_annotation, "class "],
+                          [desc, ([desc_signature, ([desc_annotation, ("class", desc_sig_space)],
                                                     [desc_name, "Class"])],
                                   [desc_content, (addnodes.index,
                                                   desc)])]))
     assert_node(doctree[1][1][0], addnodes.index,
                 entries=[('single', 'meth() (Class static method)', 'Class.meth', '', None)])
-    assert_node(doctree[1][1][1], ([desc_signature, ([desc_annotation, "static "],
+    assert_node(doctree[1][1][1], ([desc_signature, ([desc_annotation, ("static", desc_sig_space)],
                                                      [desc_name, "meth"],
                                                      [desc_parameterlist, ()])],
                                    [desc_content, ()]))
@@ -811,22 +835,27 @@ def test_pyattribute(app):
     domain = app.env.get_domain('py')
     doctree = restructuredtext.parse(app, text)
     assert_node(doctree, (addnodes.index,
-                          [desc, ([desc_signature, ([desc_annotation, "class "],
+                          [desc, ([desc_signature, ([desc_annotation, ("class", desc_sig_space)],
                                                     [desc_name, "Class"])],
                                   [desc_content, (addnodes.index,
                                                   desc)])]))
     assert_node(doctree[1][1][0], addnodes.index,
                 entries=[('single', 'attr (Class attribute)', 'Class.attr', '', None)])
     assert_node(doctree[1][1][1], ([desc_signature, ([desc_name, "attr"],
-                                                     [desc_annotation, (": ",
+                                                     [desc_annotation, ([desc_sig_punctuation, ':'],
+                                                                        desc_sig_space,
                                                                         [pending_xref, "Optional"],
                                                                         [desc_sig_punctuation, "["],
                                                                         [pending_xref, "str"],
                                                                         [desc_sig_punctuation, "]"])],
-                                                     [desc_annotation, " = ''"])],
+                                                     [desc_annotation, (desc_sig_space,
+                                                                        [desc_sig_punctuation, '='],
+                                                                        desc_sig_space,
+                                                                        "''")]
+                                                     )],
                                    [desc_content, ()]))
-    assert_node(doctree[1][1][1][0][1][1], pending_xref, **{"py:class": "Class"})
-    assert_node(doctree[1][1][1][0][1][3], pending_xref, **{"py:class": "Class"})
+    assert_node(doctree[1][1][1][0][1][2], pending_xref, **{"py:class": "Class"})
+    assert_node(doctree[1][1][1][0][1][4], pending_xref, **{"py:class": "Class"})
     assert 'Class.attr' in domain.objects
     assert domain.objects['Class.attr'] == ('index', 'Class.attr', 'attribute', False)
 
@@ -844,7 +873,7 @@ def test_pyproperty(app):
     domain = app.env.get_domain('py')
     doctree = restructuredtext.parse(app, text)
     assert_node(doctree, (addnodes.index,
-                          [desc, ([desc_signature, ([desc_annotation, "class "],
+                          [desc, ([desc_signature, ([desc_annotation, ("class", desc_sig_space)],
                                                     [desc_name, "Class"])],
                                   [desc_content, (addnodes.index,
                                                   desc,
@@ -852,16 +881,20 @@ def test_pyproperty(app):
                                                   desc)])]))
     assert_node(doctree[1][1][0], addnodes.index,
                 entries=[('single', 'prop1 (Class property)', 'Class.prop1', '', None)])
-    assert_node(doctree[1][1][1], ([desc_signature, ([desc_annotation, "abstract property "],
+    assert_node(doctree[1][1][1], ([desc_signature, ([desc_annotation, ("abstract", desc_sig_space,
+                                                                        "property", desc_sig_space)],
                                                      [desc_name, "prop1"],
-                                                     [desc_annotation, (": ",
+                                                     [desc_annotation, ([desc_sig_punctuation, ':'],
+                                                                        desc_sig_space,
                                                                         [pending_xref, "str"])])],
                                    [desc_content, ()]))
     assert_node(doctree[1][1][2], addnodes.index,
                 entries=[('single', 'prop2 (Class property)', 'Class.prop2', '', None)])
-    assert_node(doctree[1][1][3], ([desc_signature, ([desc_annotation, "class property "],
+    assert_node(doctree[1][1][3], ([desc_signature, ([desc_annotation, ("class", desc_sig_space,
+                                                                        "property", desc_sig_space)],
                                                      [desc_name, "prop2"],
-                                                     [desc_annotation, (": ",
+                                                     [desc_annotation, ([desc_sig_punctuation, ':'],
+                                                                        desc_sig_space,
                                                                         [pending_xref, "str"])])],
                                    [desc_content, ()]))
     assert 'Class.prop1' in domain.objects
@@ -906,7 +939,7 @@ def test_canonical(app):
     domain = app.env.get_domain('py')
     doctree = restructuredtext.parse(app, text)
     assert_node(doctree, (addnodes.index,
-                          [desc, ([desc_signature, ([desc_annotation, "class "],
+                          [desc, ([desc_signature, ([desc_annotation, ("class", desc_sig_space)],
                                                     [desc_addname, "io."],
                                                     [desc_name, "StringIO"])],
                                   desc_content)]))
@@ -964,7 +997,7 @@ def test_info_field_list(app):
     assert_node(doctree, (nodes.target,
                           addnodes.index,
                           addnodes.index,
-                          [desc, ([desc_signature, ([desc_annotation, "class "],
+                          [desc, ([desc_signature, ([desc_annotation, ("class", desc_sig_space)],
                                                     [desc_addname, "example."],
                                                     [desc_name, "Class"])],
                                   [desc_content, nodes.field_list, nodes.field])]))
@@ -1055,7 +1088,7 @@ def test_info_field_list_piped_type(app):
                 (nodes.target,
                  addnodes.index,
                  addnodes.index,
-                 [desc, ([desc_signature, ([desc_annotation, "class "],
+                 [desc, ([desc_signature, ([desc_annotation, ("class", desc_sig_space)],
                                            [desc_addname, "example."],
                                            [desc_name, "Class"])],
                          [desc_content, nodes.field_list, nodes.field, (nodes.field_name,
@@ -1077,6 +1110,42 @@ def test_info_field_list_piped_type(app):
                 **{"py:module": "example", "py:class": "Class"})
 
 
+def test_info_field_list_Literal(app):
+    text = (".. py:module:: example\n"
+            ".. py:class:: Class\n"
+            "\n"
+            "   :param age: blah blah\n"
+            "   :type age: Literal['foo', 'bar', 'baz']\n")
+    doctree = restructuredtext.parse(app, text)
+
+    assert_node(doctree,
+                (nodes.target,
+                 addnodes.index,
+                 addnodes.index,
+                 [desc, ([desc_signature, ([desc_annotation, ("class", desc_sig_space)],
+                                           [desc_addname, "example."],
+                                           [desc_name, "Class"])],
+                         [desc_content, nodes.field_list, nodes.field, (nodes.field_name,
+                                                                        nodes.field_body)])]))
+    assert_node(doctree[3][1][0][0][1],
+                ([nodes.paragraph, ([addnodes.literal_strong, "age"],
+                                    " (",
+                                    [pending_xref, addnodes.literal_emphasis, "Literal"],
+                                    [addnodes.literal_emphasis, "["],
+                                    [addnodes.literal_emphasis, "'foo'"],
+                                    [addnodes.literal_emphasis, ", "],
+                                    [addnodes.literal_emphasis, "'bar'"],
+                                    [addnodes.literal_emphasis, ", "],
+                                    [addnodes.literal_emphasis, "'baz'"],
+                                    [addnodes.literal_emphasis, "]"],
+                                    ")",
+                                    " -- ",
+                                    "blah blah")],))
+    assert_node(doctree[3][1][0][0][1][0][2], pending_xref,
+                refdomain="py", reftype="class", reftarget="Literal",
+                **{"py:module": "example", "py:class": "Class"})
+
+
 def test_info_field_list_var(app):
     text = (".. py:class:: Class\n"
             "\n"
